"""
Script to select contacts that are highlighted from the contact map probability
related to IE- and IT

Process:
-   compute for each contact probability map (cpm) the Z-score: (p-<p>)/sigma.
    Where, sigma is the data std
-   Compare Z-scores as follows: select those contacts such that:
        1. have a Z-score in IE- > 1
        2. have a Z-score in IT < 1
-   Filter those contacts NOT involved in the thread
"""
import numpy as np
import matplotlib.pyplot as plt

from utils.paths import ANALYSIS_PATH

ANALYSIS_PATH = ANALYSIS_PATH / "1ucs"

# load probability maps
ie = np.load(ANALYSIS_PATH / "probability_IE-_29Oct22_CV_2Nov22_CV.npy")
it = np.load(ANALYSIS_PATH / "probability_IT_29Oct22_CV_2Nov22_CV.npy")

# compute probability - <probability>
ie_mean = np.mean(ie[ie!=0])
it_mean = np.mean(it[it!=0])
ie_std = np.std(ie[ie!=0])
it_std = np.std(it[it!=0])

ie_flat = ie[ie!=0].flatten()
it_flat = it[it!=0].flatten()

ie_dev = np.copy(ie)
it_dev = np.copy(it)
ie_dev_flat = (ie_flat - ie_mean)/ie_std
ie_dev[ie!=0] = ie_dev_flat
it_dev_flat = (it_flat - it_mean)/it_std
it_dev[it!=0] = it_dev_flat

diff = np.zeros(ie.shape)
diff = (ie_dev>1) & (it_dev<1)

# filtering
thr = 0

diff_filtered = np.zeros(diff.shape)
diff_filtered[diff>thr] = 1

# highlighting only thread related contacts
diff_filtered[:,:24] = 0 # before thread
diff_filtered[6:,:] = 0 # "below" thread

# plot
plt.imshow(diff_filtered, cmap="binary")
plt.colorbar()
plt.show()

# print
arr1, arr2 = np.nonzero(diff_filtered)
out = [(i1, i2) for i1, i2 in zip(arr1, arr2)]
print(out)
