"""
Script which collects and saves the list of trajectories
that pass through the intermediate state of 1ucs.
The script saves the run ID, hence the ID specified in the
directory containing the trajectory.

The list is manually cured.

The classification is done using the 1ucs_automatic_classification.py
here a copy of the result is reported.
"""
from pathlib import Path

import numpy as np

# Path where to save
outpath = Path("/mnt/GO_ANALYSIS")

# ######################################### 29Oct22_CV
# 1ucs; folding at 0.9 T_f
prot = "1ucs"
dataset = "29Oct22_CV"
THR = [49, 2, 18, 12, 43, 5, 30]
BT = []

# check that all THR and BT trajs are classified also as folded 
folded = np.load(outpath / prot / f"folded_trajectories_{dataset}.npy")
for thr_traj in THR:
    assert thr_traj in folded
for bt_traj in BT:
    assert bt_traj in folded

np.save(outpath / prot / f"THR_traj_{dataset}.npy", THR)
np.save(outpath / prot / f"BT_traj_{dataset}.npy", BT)

######################################### 2Nov22_CV
# 1ucs; folding at 0.9 T_f
prot = "1ucs"
dataset = "2Nov22_CV"
THR = [64, 60, 99, 63, 68, 90, 86, 57]
BT = [57]

# check that all THR and BT trajs are classified also as folded
folded = np.load(outpath / prot / f"folded_trajectories_{dataset}.npy")
for thr_traj in THR:
    assert thr_traj in folded, print(thr_traj, folded)
for bt_traj in BT:
    assert bt_traj in folded, print(bt_traj, folded)

np.save(outpath / prot / f"THR_traj_{dataset}.npy", THR)
np.save(outpath / prot / f"BT_traj_{dataset}.npy", BT)


######################################### 29Oct22_CV + 2Nov22_CV
# extra for the analysis of combined datasets
THR = [49, 2, 18, 12, 43, 5, 30, 8] + [64, 60, 99, 63, 68, 90, 86, 57]
BT = [7]
prot = "1ucs"
np.save(outpath / prot / "THR_traj_29Oct22_CV_2Nov22_CV.npy", THR)
np.save(outpath / prot / "BT_traj_29Oct22_CV_2Nov22_CV.npy", BT)

######################################### 29Oct22_CV_increment + 2Nov22_CV_increment
# extra for the analysis of combined datasets
THR = [22, 42, 40] + [88, 85, 70, 58, 80, 74]
BT = [13, 1] + [53]
prot = "1ucs"
dataset = "29Oct22_CV_increment_2Nov22_CV_increment"

# check that all THR and BT trajs are classified also as folded
folded = np.load(outpath / prot / f"folded_trajectories_{dataset}.npy")
for thr_traj in THR:
    assert thr_traj in folded, print(thr_traj, folded)
for bt_traj in BT:
    assert bt_traj in folded, print(bt_traj, folded)

np.save(outpath / prot / "THR_traj_29Oct22_CV_increment_2Nov22_CV_increment.npy", THR)
np.save(outpath / prot / "BT_traj_29Oct22_CV_increment_2Nov22_CV_increment.npy", BT)
